# arirang ruby script example

class Arirang

#@ari_port = 80
#@ari_recvsize = 1024
#@ari_recvflag = 3

     def baedal
        ari_title   = "long url buffer overflow check\n"
        ari_desc    = "arirang ruby script examples\n"
        ari_author  = "pilot <pilot@monkey.org>\n"

        puts "title: #{ari_title}"
        puts "desc: #{ari_desc}"
        puts "author: #{ari_author}"
     end

     def asadal
         buf = "GET /" + "a" * 2048 + " HTTP/1.0\r\n\r\n"
         ariconnect
         response = arisend(buf)
         response.each_line do |line|
            if line =~ /500*/
                y = "#{$ari_host} - 500 Server Error Reponse\n"
                ariprint(y)
            end
         end
    end

end


