# arirang ruby script example
# export PROXY_TYPE="RELAY"
# required the -X option
# eg) arirang -X yourproxy:3128 -R caching.rb -h yourhost 
class Arirang
@ari_recvsize = 200000
@ari_recvflag = 3

     def baedal
        ari_title   = "caching only http proxy test\n"
        ari_desc    = "it is useful only in the context of HTTP requests\n"
        ari_author  = "pilot <pilot@monkey.org>\n"

        puts "title: #{ari_title}"
        puts "desc: #{ari_desc}"
        puts "author: #{ari_author}"
     end

     def asadal
         ariconnect
         buf = "GET http://#{$ari_host}/ HTTP/1.0\r\n\r\n"
         response = arisend(buf)
         z = "#{$ari_host} - " + response
         ariprint(z)
     end


end

