# arirang ruby script blank file
# by pilot
class Arirang

#@ari_port = 80
#@ari_recvsize = 1024
#@ari_recvflag = 3

    def baedal
        #
        #arirang ruby script information
        #
        #ari_title  = "\n"
        #ari_desc   = "\n"
        #ari_author = "\n"
        #ari_license = "\n"

        #puts "title: #{ari_title}"
        #puts "desc: #{ari_desc}"
        #puts "author: #{ari_author}"
        #puts "license: #{ari_license}"
    end

    def asadal
        #
        # arirang ruby script main part
        #
    end

end

